@@ -24,6 +24,7 @@
 #include <qwhatsthis.h>
 #include <qfile.h>
 #include <qfont.h>
+#include <qcolor.h>
 #include <qframe.h>
 #include <qtextstream.h>
 #include <qcombobox.h>
@@ -50,8 +51,17 @@
 #define CONFIGFILE ".cdcatconf"
 #endif
 
+
+
+
+
 CdCatConfig::CdCatConfig(void)
  {
+ 
+ // The default values of config.
+ // If you delete the config file (or prats of file)
+ // the values will be set to these:
+
   startpar   = false;
   startfn    = "";
  
@@ -63,44 +73,53 @@ CdCatConfig::CdCatConfig(void)
   nice       = true;
   cdrompath  = "";
   hlist      = 0;
+  autosave   = false; 
   
   readtag    = true;
   v1_over_v2 = false;
   readinfo   = true;
   readcontent = false;
-  readcfiles = "*.nfo;*.dzi";
+  readcfiles = "*.nfo;*.diz";
   readclimit = 32*1024;
   
   readavii   = true;
   
-  find_cs =false;
-  find_em =true;
-  find_di =true;
-  find_fi =true;
-  find_co =true;
-  find_ct =true;
-  find_mco=true;
-  find_mar=true;
-  find_mti=true;
-  find_mal=true;
-  findX=10;
-  findY=10;
-  findWidth=515;
-  findHeight=365;
+  find_cs    = false;
+  find_em    = false;
+  find_di    = true;
+  find_fi    = true;
+  find_co    = true;
+  find_ct    = true;
+  find_mco   = true;
+  find_mar   = true;
+  find_mti   = true;
+  find_mal   = true;
+  findX      = 10;
+  findY      = 10;
+  findWidth  = 515;
+  findHeight = 365;
   
-  mainP1=200;
-  mainP2=270;
-  mainP3=170;
+  mainP1     = 200;
+  mainP2     = 270;
+  mainP3     = 170;
 			    
   windowSize.setWidth(windowSize_width=640);
   windowSize.setHeight(windowSize_height=480);
   windowPos.setX(5);
   windowPos.setY(5);
   
+  comm_bg    = new QColor(255,225,0);
+  comm_stext = new QColor(0,0,0);
+  comm_vtext = new QColor(10,10,255);
+  comm_fr    = new QColor(0,0,0);
+  
+  linkf      = true;
+
+  
 #ifndef _WIN32
   mounteject = false;
 #else
-  lang       ="eng";  
+  lang       = "eng";  
 #endif
 
  }
@@ -143,6 +162,20 @@ int CdCatConfig::startProgram(DataBase **dbp,QWidget *mw)
  }
 
 
+
+int secv(const char *s,int i)
+ {
+   int v1,v2,v3;
+   
+   sscanf(s,"%d,%d,%d",&v1,&v2,&v3);
+   
+   if(i == 0) return v1;
+   if(i == 1) return v2;
+   if(i == 2) return v3;
+   return 0;
+ }
+	      
+
 int CdCatConfig::readConfig(void)
   {
    int error = 0;
@@ -224,6 +257,15 @@ int CdCatConfig::readConfig(void)
                continue;
             }
 
+            if(var=="autosave")
+            {
+               if(val=="true")
+                  autosave=true;
+               else
+                  autosave=false;
+               continue;
+            }
+
             if(var=="ownfont")
             {
                if(val=="true")
@@ -470,6 +512,63 @@ int CdCatConfig::readConfig(void)
             }
 
 
+            if (var=="comment_bg_color")
+            {
+	       int r=0,g=0,b=0;
+	       
+	       r=secv(val,0);
+	       g=secv(val,1);
+	       b=secv(val,2);
+	       
+	       comm_bg->setRgb(r,g,b);
+               continue;
+            }
+
+            if (var=="comment_fr_color")
+            {
+	       int r=0,g=0,b=0;
+	       
+	       r=secv(val,0);
+	       g=secv(val,1);
+	       b=secv(val,2);
+
+	       comm_fr->setRgb(r,g,b);
+               continue;
+            }
+
+            if (var=="comment_ts_color")
+            {
+	       int r=0,g=0,b=0;
+	       
+	       r=secv(val,0);
+	       g=secv(val,1);
+	       b=secv(val,2);
+	       
+	       comm_stext->setRgb(r,g,b);
+               continue;
+            }
+
+            if (var=="comment_td_color")
+            {
+	       int r=0,g=0,b=0;
+	       
+	       r=secv(val,0);
+	       g=secv(val,1);
+	       b=secv(val,2);
+	       
+	       comm_vtext->setRgb(r,g,b);
+               continue;
+            }
+	    
+	   if(var=="catalog_link_is_first")
+            {
+               if(val=="true")
+                  linkf=true;
+               else
+                  linkf=false;
+               continue;
+            }
+    
 
            fprintf(stderr,"Unknown key founded: %s\n",(const char *)var);
            error = 1;
@@ -493,7 +592,7 @@ int CdCatConfig::writeConfig(void)
 #else
    if(getenv("HOME") == NULL)
    {
-      QMessageBox::warning(0,tr("Error during write config..."),
+      QMessageBox::warning(0,tr("Error while saving config file..."),
                             tr("I can't get the $HOME environment variable.\nIt is necessary couse I'd like to save the config file into your home directory.")
                            ,tr("Ok"),0);
 
@@ -551,11 +650,16 @@ int CdCatConfig::writeConfig(void)
       else
          str << "autoload_file="+autoloadfn << endl;
 
+      if (autosave)
+         str << "autosave=true" << endl;
+      else
+         str << "autosave=false" << endl;
+      
       if (nice)
          str << "niceformat=true" << endl;
       else
          str << "niceformat=false" << endl;
-      ;
+      
 
       str << "cdrompath="+cdrompath << endl;
 
@@ -663,16 +767,27 @@ int CdCatConfig::writeConfig(void)
       str << "read_content_files=" << readcfiles << endl;            	 
       str << "read_content_limit=" << readclimit << endl;            	 
 
+      str << "comment_bg_color=" << comm_bg->red() <<","<< comm_bg->green() <<","<< comm_bg->blue() <<endl;
+      str << "comment_fr_color=" << comm_fr->red() <<","<< comm_fr->green() <<","<< comm_fr->blue() <<endl;
+      str << "comment_ts_color=" << comm_stext->red() <<","<< comm_stext->green() <<","<< comm_stext->blue() <<endl;
+      str << "comment_td_color=" << comm_vtext->red() <<","<< comm_vtext->green() <<","<< comm_vtext->blue() <<endl;
+
+      if(linkf)
+         str << "catalog_link_is_first=true" <<endl;
+      else	 
+         str << "catalog_link_is_first=false" <<endl;
+
+
       f.close();
       return 0;
    }
    else
    {
 #ifdef _WIN32
-      QMessageBox::warning(0,tr("Error during write config..."),tr("I can't create or rewrite the ./cdcat.cfg file ")
+      QMessageBox::warning(0,tr("Error while saving config file..."),tr("I can't create or rewrite the ./cdcat.cfg file ")
                            ,tr("Ok"),0);
 #else
-      QMessageBox::warning(0,tr("Error during write config..."),tr("I can't create or rewrite the $(HOME)/.cdcatconfig file ")
+      QMessageBox::warning(0,tr("Error while saving config file..."),tr("I can't create or rewrite the $(HOME)/.cdcatconfig file ")
                            ,tr("Ok"),0);
 #endif
       return 1;
@@ -690,7 +805,7 @@ ConfigDialog::ConfigDialog(CdCatMainWidget* parent, const char* name, bool modal
    p = parent;
 
    setSizeGripEnabled( TRUE );
-   ConfigDialogBaseLayout = new QGridLayout( this, 1, 1, 16, 6, "ConfigDialogBaseLayout");
+   ConfigDialogBaseLayout = new QGridLayout( this, 1, 1, 18, 6, "ConfigDialogBaseLayout");
 
    layout1 = new QHBoxLayout( 0, 0, 6, "layout1");
    cbAutoload = new QCheckBox( this, "cbAutoload" );
@@ -732,14 +847,24 @@ ConfigDialog::ConfigDialog(CdCatMainWidget* parent, const char* name, bool modal
    line2->setFrameShape( QFrame::HLine );
    ConfigDialogBaseLayout->addWidget( line2, 5, 0 );
 
+   cbAutosave = new QCheckBox( this, "cbAutos" );
+   ConfigDialogBaseLayout->addWidget( cbAutosave, 6, 0 );
+
+   line8 = new QFrame( this, "line8" );
+   line8->setFrameShape( QFrame::HLine );
+   line8->setFrameShadow( QFrame::Sunken );
+   line8->setFrameShape( QFrame::HLine );
+   ConfigDialogBaseLayout->addWidget( line8, 7, 0 );
+
+
    cbNice = new QCheckBox( this, "cbNice" );
-   ConfigDialogBaseLayout->addWidget( cbNice, 6, 0 );
+   ConfigDialogBaseLayout->addWidget( cbNice, 8, 0 );
 
    line3 = new QFrame( this, "line3" );
    line3->setFrameShape( QFrame::HLine );
    line3->setFrameShadow( QFrame::Sunken );
    line3->setFrameShape( QFrame::HLine );
-   ConfigDialogBaseLayout->addWidget( line3, 7, 0 );
+   ConfigDialogBaseLayout->addWidget( line3, 9, 0 );
 
 
    layout5 = new QHBoxLayout( 0, 0, 6, "layout5");
@@ -751,20 +876,20 @@ ConfigDialog::ConfigDialog(CdCatMainWidget* parent, const char* name, bool modal
    searchButton2->setText("...");
    searchButton2->setFlat( FALSE );
    layout5->addWidget( searchButton2 );
-   ConfigDialogBaseLayout->addLayout( layout5, 8, 0 );
+   ConfigDialogBaseLayout->addLayout( layout5, 10, 0 );
 
    line4 = new QFrame( this, "line4" );
    line4->setFrameShape( QFrame::HLine );
    line4->setFrameShadow( QFrame::Sunken );
    line4->setFrameShape( QFrame::HLine );
-   ConfigDialogBaseLayout->addWidget( line4, 9, 0 );
+   ConfigDialogBaseLayout->addWidget( line4, 11, 0 );
 
 
 
 #ifndef _WIN32
 
    cbMoEj = new QCheckBox( this, "cbMoEj" );
-   ConfigDialogBaseLayout->addWidget( cbMoEj, 10, 0 );
+   ConfigDialogBaseLayout->addWidget( cbMoEj, 12, 0 );
 #else
    layout9   = new QHBoxLayout(0,0,5,"layout9");
    cbLang    = new QComboBox(this,"languageselector");
@@ -773,7 +898,7 @@ ConfigDialog::ConfigDialog(CdCatMainWidget* parent, const char* name, bool modal
    layout9->insertWidget (1,cbLang);
    layout9->insertWidget (2,langLabel);
    layout9->insertSpacing(3,5);
-   ConfigDialogBaseLayout->addLayout( layout9, 10, 0 );
+   ConfigDialogBaseLayout->addLayout( layout9, 12, 0 );
    
    /*scanning existing languages:*/
    cbLang->insertItem("eng",0);
@@ -804,7 +929,7 @@ ConfigDialog::ConfigDialog(CdCatMainWidget* parent, const char* name, bool modal
    line5->setFrameShape( QFrame::HLine );
    line5->setFrameShadow( QFrame::Sunken );
    line5->setFrameShape( QFrame::HLine );
-   ConfigDialogBaseLayout->addWidget( line5, 11, 0 );
+   ConfigDialogBaseLayout->addWidget( line5, 13, 0 );
 
    layout6 = new QHBoxLayout( 0, 0, 6, "layout6");
    spinHistorySize = new QSpinBox( this,"spinHistorySize" );
@@ -812,23 +937,23 @@ ConfigDialog::ConfigDialog(CdCatMainWidget* parent, const char* name, bool modal
    layout6->addWidget( spinHistorySize );
    labHistorySize = new QLabel( this, "labHistorySize" );
    layout6->addWidget( labHistorySize );
-   ConfigDialogBaseLayout->addLayout( layout6, 12, 0 );
+   ConfigDialogBaseLayout->addLayout( layout6, 14, 0 );
 
    line6 = new QFrame( this, "line6" );
    line6->setFrameShape( QFrame::HLine );
    line6->setFrameShadow( QFrame::Sunken );
    line6->setFrameShape( QFrame::HLine );
-   ConfigDialogBaseLayout->addWidget( line6, 13, 0 );
+   ConfigDialogBaseLayout->addWidget( line6, 15, 0 );
 
 
    riButton = new QPushButton(this,"ributton");
-   ConfigDialogBaseLayout->addWidget( riButton, 14, 0 );
+   ConfigDialogBaseLayout->addWidget( riButton, 16, 0 );
    
    line7 = new QFrame( this, "line7" );
    line7->setFrameShape( QFrame::HLine );
    line7->setFrameShadow( QFrame::Sunken );
    line7->setFrameShape( QFrame::HLine );
-   ConfigDialogBaseLayout->addWidget( line7, 15, 0 );
+   ConfigDialogBaseLayout->addWidget( line7, 17, 0 );
 
    layout7 = new QHBoxLayout( 0, 0, 6, "layout7");
    QSpacerItem* spacer = new QSpacerItem( 110, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
@@ -847,7 +972,7 @@ ConfigDialog::ConfigDialog(CdCatMainWidget* parent, const char* name, bool modal
    QSpacerItem* spacer_2 = new QSpacerItem( 130, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout7->addItem( spacer_2 );
 
-   ConfigDialogBaseLayout->addLayout( layout7, 16, 0 );
+   ConfigDialogBaseLayout->addLayout( layout7, 18, 0 );
    
    connect( searchButton2, SIGNAL( clicked() ), this, SLOT( cdrombutton() ) );
 
@@ -880,6 +1005,7 @@ ConfigDialog::ConfigDialog(CdCatMainWidget* parent, const char* name, bool modal
 
    cbNice->setChecked(p->cconfig->nice);
    cbAutoload->setChecked(p->cconfig->autoload);
+   cbAutosave->setChecked(p->cconfig->autosave);
    if(!p->cconfig->autoloadfn.isEmpty())
       filename->setText(p->cconfig->autoloadfn);
    spinFontSize->setValue(p->cconfig->fsize);
@@ -910,10 +1036,11 @@ void ConfigDialog::languageChange()
 {
    setCaption( tr( "Configure  CdCat..." ) );
    cbAutoload->setText( tr( "Autoload DataBase on startup" ) );
+   cbAutosave->setText( tr( "Automatically save the database after every scan (for dafety sake)" ) );
    cbNice->setText( tr( "Save the XML-db.file nicer format(needs more space)" ) );
    cancelButton->setText( tr( "Cancel" ) );
    okButton->setText( tr( "Ok" ) );
-   riButton->setText( tr( "Select readable items" ) );
+   riButton->setText( tr( "Select additional items to read") );
    cbOwnFont->setText(tr("Use own font size"));
    lab->setText(tr("Application font size.(must restart cdcat!) "));
    labHistorySize->setText(tr("Number of history entries"));
@@ -950,6 +1077,7 @@ void ConfigDialog::okExit()
 {
    p->cconfig->nice        = cbNice->isChecked();
    p->cconfig->autoload    = cbAutoload->isChecked();
+   p->cconfig->autosave    = cbAutosave->isChecked();
    p->cconfig->autoloadfn  = filename->text();
    p->cconfig->ownfont     = cbOwnFont->isChecked();
    p->cconfig->fsize       = spinFontSize->value();
