@@ -815,6 +815,7 @@ int DataBase::scanFileProp(QFileInfo *fi,DBFile *fc)
 	  {
 	   int i;
 	   QString got = parseAviHeader(filePTR);
+	   rewind(filePTR);
 	   fclose(filePTR);
 	   
 	   char *info = new char[got.length() + 10];    
@@ -1245,7 +1246,11 @@ Node * DataBase::getDirectoryNode(Node *meddir,char *name)
    t=meddir->child;   
    while(t != NULL)
     {
-     if(t->type != HC_DIRECTORY) continue;
+     if(t->type != HC_DIRECTORY) 
+      {
+       t=t->next;
+       continue;
+      } 
      if(!strcmp(t->getNameOf(),name))
         return t;
      t=t->next;
@@ -1279,7 +1284,11 @@ Node * DataBase::getFileNode(Node *directory,char *name)
    t=directory->child;   
    while(t != NULL)
     {
-     if(t->type != HC_FILE) continue;
+     if(t->type != HC_FILE)
+       {
+        t=t->next;
+        continue;
+       }	
      if(!strcmp(t->getNameOf(),name))
         return t;
      t=t->next;
