@@ -77,12 +77,14 @@ importGtktalogCsv::importGtktalogCsv( GuiSlave * parent, QString separator, QStr
 	if ( !filename.isEmpty() ) {
 
 		if ( parent->mainw->db == NULL )
-			parent->newEvent();
+		 {
+			if(parent->newEvent() == -1 ) return;
+		 }	
 		else {
 			if ( createdatabase ) {
 				while ( parent->closeEvent() != 0 )
 					;
-				parent->newEvent();
+				if(parent->newEvent() == -1 ) return;
 			}
 		}
 
@@ -599,18 +601,21 @@ extern "C" {
 }
 
 importGtktalogXml::importGtktalogXml( GuiSlave * parent, QString filename, bool createdatabase ) {
+        progress = NULL;
 	this->guislave = parent;
 	bool import_ok = true;
 	last_tag = "";
 	if ( !filename.isEmpty() ) {
 
 		if ( parent->mainw->db == NULL )
-			parent->newEvent();
+		 {
+			if(parent->newEvent() == -1 ) return;
+		 }	
 		else {
 			if ( createdatabase ) {
 				while ( parent->closeEvent() != 0 )
 					;
-				parent->newEvent();
+				if(parent->newEvent() == -1 ) return;
 			}
 		}
 
@@ -741,7 +746,8 @@ importGtktalogXml::importGtktalogXml( GuiSlave * parent, QString filename, bool
 }
 
 importGtktalogXml::~importGtktalogXml() {
-	delete ( progress );
+        if (progress != NULL)
+    	    delete  progress ;
 }
 
 int importGtktalogXml::addNewItem( QString medianame, QString path, QString filename, float size, QDateTime datetime ) {
@@ -1256,6 +1262,7 @@ extern "C" {
 
 
 importWhereIsItXml::importWhereIsItXml( GuiSlave * parent, QString filename, bool createdatabase ) {
+        progress = NULL;
 	this->guislave = parent;
 	bool import_ok = true;
 	last_tag = "";
@@ -1263,12 +1270,14 @@ importWhereIsItXml::importWhereIsItXml( GuiSlave * parent, QString filename, boo
 	if ( !filename.isEmpty() ) {
 
 		if ( parent->mainw->db == NULL )
-			parent->newEvent();
+		 {
+			if(parent->newEvent() == -1 ) return;
+		 }	
 		else {
 			if ( createdatabase ) {
 				while ( parent->closeEvent() != 0 )
-					;
-				parent->newEvent();
+				      ;
+				if(parent->newEvent() == -1 ) return;
 			}
 		}
 
@@ -1488,7 +1497,8 @@ importWhereIsItXml::importWhereIsItXml( GuiSlave * parent, QString filename, boo
 }
 
 importWhereIsItXml::~importWhereIsItXml() {
-	delete ( progress );
+	if(progress != NULL)
+	    delete  progress;
 }
 
 void importWhereIsItXml::setProgress() {
@@ -1515,13 +1525,12 @@ import::import( GuiSlave * parent ) {
 	if ( d->OK == 1 ) {
 		separator = d->separator;
 		filename = d->filename;
-		createdatabase = d->newdatabase;
+		createdatabase = d->createdatabase;
 		correctbadstyle = d->correctbadstyle;
 		separator = d->separator;
 		type = d->type;
 
 		delete d;
-
 		if ( type == 0 )
 			importGtktalogCsv import0( parent, separator, filename, createdatabase, correctbadstyle );
 		if ( type == 1 )
