@@ -1,5 +1,32 @@
 <!DOCTYPE TS><TS>
 <defaultcodec>iso8859-1</defaultcodec>
+<context>
+    <name>AddLnk</name>
+    <message>
+        <source>Add a &quot;Catalog Link&quot; to the database</source>
+        <translation>Dodaj &quot;Łącze do katalogu&quot; do bazy danych</translation>
+    </message>
+    <message>
+        <source>Location of the .hcf file:</source>
+        <translation>Polozenie pliku .hcf:</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Anuluj</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <source>CdCat databases (*.hcf )</source>
+        <translation>Bazy danych CdCat&apos;a (*.hcf)</translation>
+    </message>
+    <message>
+        <source>Open a file...</source>
+        <translation>Otworz plik...</translation>
+    </message>
+</context>
 <context>
     <name>CdCatConfig</name>
     <message>
@@ -20,7 +47,7 @@ Sprawdź plik, albo zmień ustawienia opcji automatycznego ładowania plku w Ust
     </message>
     <message>
         <source>Error during write config...</source>
-        <translation>Błąd podczas zapisywania pliku konfiguracyjnego...</translation>
+        <translation type="obsolete">Błąd podczas zapisywania pliku konfiguracyjnego...</translation>
     </message>
     <message>
         <source>I can&apos;t get the HOME environment variable.
@@ -57,12 +84,16 @@ Jest potrzebna, gdyż chciałem zapisać ustawienia do twojego katalogu domowego
         <source>I can&apos;t create or rewrite the $(HOME)/.cdcatconfig file </source>
         <translation>Nie mogę utworzyć albo nadpisać $(HOME)/.cdcatconfig</translation>
     </message>
+    <message>
+        <source>Error while saving config file...</source>
+        <translation>Błąd podczas zapisywania pliku konfiguracyjnego...</translation>
+    </message>
 </context>
 <context>
     <name>CdCatMainWidget</name>
     <message>
         <source>No selected item</source>
-        <translation>Brak zaznaczonych obiektów</translation>
+        <translation type="obsolete">Brak zaznaczonych obiektów</translation>
     </message>
     <message>
         <source>Directory Tree</source>
@@ -194,7 +225,7 @@ Jest potrzebna, gdyż chciałem zapisać ustawienia do twojego katalogu domowego
     </message>
     <message>
         <source>Rescan the selected media from the disk.</source>
-        <translation>Odczytaj ponownie wybrany nośnik.</translation>
+        <translation type="obsolete">Odczytaj ponownie wybrany nośnik.</translation>
     </message>
     <message>
         <source>Delete the selected media from the catalog.</source>
@@ -252,6 +283,84 @@ Jest potrzebna, gdyż chciałem zapisać ustawienia do twojego katalogu domowego
         <source>Save the catalog to a new file.</source>
         <translation>Zapisz katalog do nowego pliku.</translation>
     </message>
+    <message>
+        <source>Add a link to a CdCAt Catalog...</source>
+        <translation>Dodaj łącze do katalogu CdCat&apos;a...</translation>
+    </message>
+    <message>
+        <source>Set Colors...</source>
+        <translation>Ustaw kolory...</translation>
+    </message>
+    <message>
+        <source>No item selected</source>
+        <translation>Niewybrano żadnego elementu</translation>
+    </message>
+    <message>
+        <source>Rescan the selected media.</source>
+        <translation>Skanuj ponownie wybrany nośnik.</translation>
+    </message>
+    <message>
+        <source>Seek in the panel</source>
+        <translation>Szukaj w panelu</translation>
+    </message>
+</context>
+<context>
+    <name>ColorSchemePreview</name>
+    <message>
+        <source>Title:</source>
+        <translation>Tytuł:</translation>
+    </message>
+    <message>
+        <source>Road To Hell</source>
+        <translation>Road To Hell</translation>
+    </message>
+</context>
+<context>
+    <name>ColorSettings</name>
+    <message>
+        <source>ColorSettings</source>
+        <translation>UstawieniaKoloru</translation>
+    </message>
+    <message>
+        <source>Comment area background and the file higlighting line</source>
+        <translation>Tło okna z komentarzem oraz podświetlenie linia zaznaczenia</translation>
+    </message>
+    <message>
+        <source>Frame of comment area</source>
+        <translation>Ramka okna z komentarzem</translation>
+    </message>
+    <message>
+        <source>Comment window static text (Program text)</source>
+        <translation>Stały tekst komentarza (Tekst z programu)</translation>
+    </message>
+    <message>
+        <source>Comment window variable text (Data)</source>
+        <translation>Zmienny tekst komentarza (Dane)</translation>
+    </message>
+    <message>
+        <source>color</source>
+        <translation>kolor</translation>
+    </message>
+    <message>
+        <source>Red:</source>
+        <translation>Czerwony:</translation>
+    </message>
+    <message>
+        <source>Green:</source>
+        <translation>Zielony:</translation>
+    </message>
+    <message>
+        <source>Blue:</source>
+        <translation>Niebieski:</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Anuluj</translation>
+    </message>
 </context>
 <context>
     <name>CommentWidget</name>
@@ -293,7 +402,7 @@ Jest potrzebna, gdyż chciałem zapisać ustawienia do twojego katalogu domowego
     </message>
     <message>
         <source>Last moification:</source>
-        <translation>Ostatnia zmiana:</translation>
+        <translation type="obsolete">Ostatnia zmiana:</translation>
     </message>
     <message>
         <source>Owner:</source>
@@ -339,6 +448,18 @@ Jest potrzebna, gdyż chciałem zapisać ustawienia do twojego katalogu domowego
         <source>There is no selected element.</source>
         <translation>Nie ma wybranego elementu.</translation>
     </message>
+    <message>
+        <source> Link to a CdCat catalog</source>
+        <translation>Łącze do katalogu CdCat&apos;a</translation>
+    </message>
+    <message>
+        <source>Location:</source>
+        <translation>Położenie:</translation>
+    </message>
+    <message>
+        <source>Last modification:</source>
+        <translation>Ostania zmiana:</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -400,12 +521,20 @@ Jest potrzebna, gdyż chciałem zapisać ustawienia do twojego katalogu domowego
     </message>
     <message>
         <source>Select readable items</source>
-        <translation>Wybierz odczywywane pliki</translation>
+        <translation type="obsolete">Wybierz odczywywane pliki</translation>
     </message>
     <message>
         <source>Choose a file to load automatically!</source>
         <translation>Wybierz plik do automatycznego ładowania!</translation>
     </message>
+    <message>
+        <source>Automatically save the database after every scan (for dafety sake)</source>
+        <translation>Automatycznie zapisz baze danych po każdym skanowaniu (na wszelki wypadek)</translation>
+    </message>
+    <message>
+        <source>Select additional items to read</source>
+        <translation>Wybierz odczywywane pliki</translation>
+    </message>
 </context>
 <context>
     <name>DataBase</name>
@@ -419,7 +548,7 @@ Jest potrzebna, gdyż chciałem zapisać ustawienia do twojego katalogu domowego
     </message>
     <message>
         <source>There is not opened database!</source>
-        <translation>Nie ma otwarej bazy danych!</translation>
+        <translation type="obsolete">Nie ma otwarej bazy danych!</translation>
     </message>
     <message>
         <source>I can&apos;t open the file: %1</source>
@@ -445,6 +574,14 @@ Jest potrzebna, gdyż chciałem zapisać ustawienia do twojego katalogu domowego
         <source>Symbolic link#Points to:</source>
         <translation>Powiązanie symboliczne#Wskazuje na:</translation>
     </message>
+    <message>
+        <source>Error while parsing file: %1</source>
+        <translation>Błąd podczas parsowania pliku: %1</translation>
+    </message>
+    <message>
+        <source>No database opened!</source>
+        <translation>Nie otwarto żadnej bazy danych!</translation>
+    </message>
 </context>
 <context>
     <name>DirectoryView</name>
@@ -457,11 +594,11 @@ Jest potrzebna, gdyż chciałem zapisać ustawienia do twojego katalogu domowego
     <name>GuiSlave</name>
     <message>
         <source>No opened database.</source>
-        <translation>Brak otwartej bazy danych.</translation>
+        <translation type="obsolete">Brak otwartej bazy danych.</translation>
     </message>
     <message>
         <source>No selected item.</source>
-        <translation>Brak zaznaczonych obiektów.</translation>
+        <translation type="obsolete">Brak zaznaczonych obiektów.</translation>
     </message>
     <message>
         <source>Directory</source>
@@ -603,7 +740,7 @@ baza danych może być niekompletna</translation>
     </message>
     <message>
         <source>The Resoult:</source>
-        <translation>Wynik:</translation>
+        <translation type="obsolete">Wynik:</translation>
     </message>
     <message>
         <source>The size of &quot;%1&quot; : 
@@ -725,12 +862,60 @@ I understand maximum %1 datafile version but readed %2
 
 Strongly recommended to upgrade your cdcat!!!
 Homepage: %3</source>
-        <translation>Plik z bazą danych pochodzi z nowszej wersji cdcat&apos;a:
+        <translation type="obsolete">Plik z bazą danych pochodzi z nowszej wersji cdcat&apos;a:
 Rozumiem maksymalnie wersje %1 bazy danych, ale odczytałem %2
 
 Zachęcam do zainstalowania nowej wersji cdcat&apos;a!!!
 Strona domowa: %3</translation>
     </message>
+    <message>
+        <source>Catalog Link</source>
+        <translation>Łącze do katalogu</translation>
+    </message>
+    <message>
+        <source>Follow the link (Open it) !</source>
+        <translation>Podążaj za łączem (Otwórz je) !</translation>
+    </message>
+    <message>
+        <source>Add a link to a CdCAt Catalog...</source>
+        <translation>Dodaj łącze do katalogu CdCat&apos;a...</translation>
+    </message>
+    <message>
+        <source>The link is empty.</source>
+        <translation>Łącze jest puste.</translation>
+    </message>
+    <message>
+        <source>Number</source>
+        <translation>Numer</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Rozmiar</translation>
+    </message>
+    <message>
+        <source>The database file has newer version than this version of cdcat can work with:
+I understand maximum %1 datafile version but readed %2
+
+Strongly recommended to upgrade your cdcat!!!
+Homepage: %3</source>
+        <translation>Plik z bazą danych pochodzi z nowszej wersji niż taka jaką potrafie oczytać:
+Rozumiem maksymalnie wersje %1 bazy danych, ale odczytałem %2
+
+Zachęcam do zainstalowania nowej wersji cdcat&apos;a!!!
+Strona domowa: %3</translation>
+    </message>
+    <message>
+        <source>No database opened.</source>
+        <translation>Nie otwarto żadnej bazy danych.</translation>
+    </message>
+    <message>
+        <source>No item selected.</source>
+        <translation>Niewybrano żadnego elementu.</translation>
+    </message>
+    <message>
+        <source>The resoult:</source>
+        <translation>Rezultat:</translation>
+    </message>
 </context>
 <context>
     <name>HDirectoryView</name>
@@ -802,17 +987,17 @@ Strona domowa: %3</translation>
     </message>
     <message>
         <source>Seperator:</source>
-        <translation>Separator:</translation>
+        <translation type="obsolete">Separator:</translation>
     </message>
     <message>
         <source>This is the seperator in dataline
 &lt;path&gt;SEPERATOR&lt;size&gt;SEPERATOR&lt;date&gt;&lt;space&gt;&lt;time&gt;</source>
-        <translation>To jest separator w lini danych
+        <translation type="obsolete">To jest separator w lini danych
 &lt;ścieżka&gt;SEPERATOR&lt;rozmiar&gt;SEPERATOR&lt;data&gt;&lt;rozmiar&gt;&lt;czas&gt;</translation>
     </message>
     <message>
         <source>Seperator in data line</source>
-        <translation>Separator w lini danych</translation>
+        <translation type="obsolete">Separator w lini danych</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -824,7 +1009,7 @@ Strona domowa: %3</translation>
     </message>
     <message>
         <source>...</source>
-        <translation type="obsolete">...</translation>
+        <translation>...</translation>
     </message>
     <message>
         <source>Open file dialog</source>
@@ -840,7 +1025,7 @@ Strona domowa: %3</translation>
     </message>
     <message>
         <source>You must be fill the &quot;Filename&quot; field!</source>
-        <translation type="obsolete">Musisz uzupełnić pole &quot;Nazwa pliku&quot;!</translation>
+        <translation>Musisz uzupełnić pole &quot;Nazwa pliku&quot;!</translation>
     </message>
     <message>
         <source>Ok</source>
@@ -868,7 +1053,7 @@ Strona domowa: %3</translation>
     </message>
     <message>
         <source>Correct bad style of gtktalog export</source>
-        <translation>Popraw zły sposób eksportu z gtktalog</translation>
+        <translation type="obsolete">Popraw zły sposób eksportu z gtktalog</translation>
     </message>
     <message>
         <source>Import database (csv/gtktalog)</source>
@@ -876,15 +1061,15 @@ Strona domowa: %3</translation>
     </message>
     <message>
         <source>&amp;Text (csv)</source>
-        <translation type="obsolete">&amp;Text (csv)</translation>
+        <translation>&amp;Text (csv)</translation>
     </message>
     <message>
         <source>&amp;XML (gtktalog)</source>
-        <translation>&amp;XML (gtktalog)</translation>
+        <translation type="obsolete">&amp;XML (gtktalog)</translation>
     </message>
     <message>
         <source>Select the type of import</source>
-        <translation>Wybierz rodzaj importowania</translation>
+        <translation type="obsolete">Wybierz rodzaj importowania</translation>
     </message>
     <message>
         <source>Select this for importing a text/csv</source>
@@ -934,12 +1119,84 @@ zostanie zmieniony na
     </message>
     <message>
         <source>File dialog for selecting file to import.</source>
-        <translation>Okno wyboru pliku do importowania.</translation>
+        <translation type="obsolete">Okno wyboru pliku do importowania.</translation>
     </message>
     <message>
         <source>Corrects bad output style of gtktalog.
 &lt;media&gt;SEPERATOR/&lt;dir&gt;/SEPERATOR/&lt;dir&gt;
  will be to
+&lt;media&gt;/&lt;dir&gt;/&lt;dir&gt;</source>
+        <translation type="obsolete">Naprawia zły styl zapisu gtktalog&apos;a.
+&lt;nośnik&gt;SEPERATOR/&lt;katalog&gt;/SEPERATOR/&lt;katalog&gt;
+zostanie zmieniony na
+&lt;nośnik&gt;/&lt;katalog&gt;/&lt;katalog&gt;</translation>
+    </message>
+    <message>
+        <source>&amp;Text (CSV)</source>
+        <translation type="obsolete">&amp;Text (CSV)</translation>
+    </message>
+    <message>
+        <source>Select this for importing text file (CSV)</source>
+        <translation type="obsolete">Zaznacz to aby importować plik tekstowy (CSV)</translation>
+    </message>
+    <message>
+        <source>Select this for importing a XML report generated with gtktalog</source>
+        <translation type="obsolete">Zaznacz to aby importować plik XML wygenerowany w gtktalog</translation>
+    </message>
+    <message>
+        <source>You must fill the &quot;Filename&quot; field!</source>
+        <translation type="obsolete">Musisz uzupełnić pole &quot;Nazwa pliku&quot;!</translation>
+    </message>
+    <message>
+        <source>You must fill the &quot;Seperator&quot; field!</source>
+        <translation type="obsolete">Musisz uzupełnić pole &quot;Seperator&quot;!</translation>
+    </message>
+    <message>
+        <source>Correct bad style from gtktalog export</source>
+        <translation>Popraw zły styl z ekspotu gtktalog&apos;u</translation>
+    </message>
+    <message>
+        <source>Separator:</source>
+        <translation>Separator:</translation>
+    </message>
+    <message>
+        <source>This is the separator in dataline
+&lt;path&gt;SEPARATOR&lt;size&gt;SEPARATOR&lt;date&gt;&lt;space&gt;&lt;time&gt;</source>
+        <translation>To jest separator w lini danych
+&lt;ścieżka&gt;SEPERATOR&lt;rozmiar&gt;SEPERATOR&lt;data&gt;&lt;rozmiar&gt;&lt;czas&gt;</translation>
+    </message>
+    <message>
+        <source>Separator in data line</source>
+        <translation>Separator w lini danych</translation>
+    </message>
+    <message>
+        <source>Gtktalog &amp;XML</source>
+        <translation>Gtktalog &amp;XML</translation>
+    </message>
+    <message>
+        <source>&amp;WhereIsIt XML (classic)</source>
+        <translation>&amp;WhereIsIt XML (klasyczny)</translation>
+    </message>
+    <message>
+        <source>Select the type of import here</source>
+        <translation>Tutaj wybierz typ importu</translation>
+    </message>
+    <message>
+        <source>Select this for importing a text import (csv)</source>
+        <translation>Użyj tego do importowania zimportowanego tekstu (csv)</translation>
+    </message>
+    <message>
+        <source>Select this for importing a xml report generated frm gtktalog</source>
+        <translation>Użyj tego do importowania raportu xml wygenerowanego przez gtktalog</translation>
+    </message>
+    <message>
+        <source>Open the file dialog for selecting file to import.</source>
+        <translation>Otwóż przeglądarke plików w celu wybrania pliku do zimportowania.</translation>
+    </message>
+    <message>
+        <source>Corrects bad output style from gtktalog.
+&lt;media&gt;SEPARATOR/&lt;dir&gt;/SEPARATOR/&lt;dir&gt;
+ will be to
 &lt;media&gt;/&lt;dir&gt;/&lt;dir&gt;</source>
         <translation>Naprawia zły styl zapisu gtktalog&apos;a.
 &lt;nośnik&gt;SEPERATOR/&lt;katalog&gt;/SEPERATOR/&lt;katalog&gt;
@@ -947,24 +1204,12 @@ zostanie zmieniony na
 &lt;nośnik&gt;/&lt;katalog&gt;/&lt;katalog&gt;</translation>
     </message>
     <message>
-        <source>&amp;Text (CSV)</source>
-        <translation>&amp;Text (CSV)</translation>
+        <source>You must be fill the &quot;Separator&quot; field!</source>
+        <translation>Musisz uzupełnić pole &quot;Separator&quot;!</translation>
     </message>
     <message>
-        <source>Select this for importing text file (CSV)</source>
-        <translation>Zaznacz to aby importować plik tekstowy (CSV)</translation>
-    </message>
-    <message>
-        <source>Select this for importing a XML report generated with gtktalog</source>
-        <translation>Zaznacz to aby importować plik XML wygenerowany w gtktalog</translation>
-    </message>
-    <message>
-        <source>You must fill the &quot;Filename&quot; field!</source>
-        <translation>Musisz uzupełnić pole &quot;Nazwa pliku&quot;!</translation>
-    </message>
-    <message>
-        <source>You must fill the &quot;Seperator&quot; field!</source>
-        <translation>Musisz uzupełnić pole &quot;Seperator&quot;!</translation>
+        <source>all files(*.*)</source>
+        <translation>wszystkie pliki (*.*)</translation>
     </message>
 </context>
 <context>
@@ -1019,7 +1264,11 @@ zostanie zmieniony na
     </message>
     <message>
         <source>Polish translation</source>
-        <translation>Polskie Tłumaczenie</translation>
+        <translation type="obsolete">Polskie Tłumaczenie</translation>
+    </message>
+    <message>
+        <source>AVI reader plugin &amp; Polish translation</source>
+        <translation>Wtyczka do odczytywania plikow AVI &amp; Polskie Tlumaczenie</translation>
     </message>
 </context>
 <context>
@@ -1156,7 +1405,7 @@ zostanie zmieniony na
     </message>
     <message>
         <source>Samples/s</source>
-        <translation>Próbek/sek</translation>
+        <translation type="obsolete">Próbek/sek</translation>
     </message>
     <message>
         <source>Bitrate</source>
@@ -1170,6 +1419,10 @@ zostanie zmieniony na
         <source>Not a RIFF/AVI file OR header broken!</source>
         <translation>Plik nie jest plikiem RIFF/AVI albo uszkodzony nagłowek!</translation>
     </message>
+    <message>
+        <source>Sample/s</source>
+        <translation>Próbek/s</translation>
+    </message>
 </context>
 <context>
     <name>SelReadable</name>
@@ -1266,7 +1519,7 @@ zostanie zmieniony na
     </message>
     <message>
         <source>Are you sure want to delete this file&apos;s content from the database?</source>
-        <translation>Jeśteś pewny, że chcesz skasować zawartośc tego pliku z bazy danych?</translation>
+        <translation type="obsolete">Jeśteś pewny, że chcesz skasować zawartośc tego pliku z bazy danych?</translation>
     </message>
     <message>
         <source>Yes</source>
@@ -1276,6 +1529,10 @@ zostanie zmieniony na
         <source>No</source>
         <translation>Nie</translation>
     </message>
+    <message>
+        <source>Sure to delete this file&apos;s content from the database?</source>
+        <translation>Napewno skasować zawartość tego pliku z bazy danych?</translation>
+    </message>
 </context>
 <context>
     <name>addDialog</name>
@@ -1387,6 +1644,10 @@ zostanie zmieniony na
         <source>You haven&apos;t selected a directory! Please select one!</source>
         <translation>Nie wybrałeś żadnego katalogu! Prosze, wybierz jakiś!</translation>
     </message>
+    <message>
+        <source>The media name can&apos;t begin with the &quot;@&quot; character!</source>
+        <translation>Nazwa nośnika nie może zaczynać się od znaku &quot;@&quot;!</translation>
+    </message>
 </context>
 <context>
     <name>borrowDialog</name>
@@ -1419,7 +1680,7 @@ zostanie zmieniony na
     <name>borrowingDialog</name>
     <message>
         <source>Borrwing info...</source>
-        <translation>Pożyczanie...</translation>
+        <translation type="obsolete">Pożyczanie...</translation>
     </message>
     <message>
         <source>Media borrowing info:</source>
@@ -1427,11 +1688,11 @@ zostanie zmieniony na
     </message>
     <message>
         <source>Only show borrowed items</source>
-        <translation>Pokazuj tylko pożyczone pozycje</translation>
+        <translation type="obsolete">Pokazuj tylko pożyczone pozycje</translation>
     </message>
     <message>
         <source>Clear all borrowing</source>
-        <translation>Usuń wszystkie oznacznia pożyczenia</translation>
+        <translation type="obsolete">Usuń wszystkie oznacznia pożyczenia</translation>
     </message>
     <message>
         <source>Media</source>
@@ -1485,6 +1746,26 @@ zostanie zmieniony na
         <source>Are you sure want to clear all borrow?</source>
         <translation>Czy napewno chcesz odznaczyć wszystkie pożyczenia?</translation>
     </message>
+    <message>
+        <source>I got it back!</source>
+        <translation>Odzyskałem go!</translation>
+    </message>
+    <message>
+        <source>&lt;&lt; </source>
+        <translation>&lt;&lt;</translation>
+    </message>
+    <message>
+        <source>Borrowing info...</source>
+        <translation>Pożyczanie...</translation>
+    </message>
+    <message>
+        <source>Show only borrowed items</source>
+        <translation>Pokaż tylko porzyczone nośniki</translation>
+    </message>
+    <message>
+        <source>Clear all borrowing info</source>
+        <translation>Usuń wszystkie informacje o porzyczaniu</translation>
+    </message>
 </context>
 <context>
     <name>commentEdit</name>
@@ -1728,7 +2009,7 @@ zostanie zmieniony na
     </message>
     <message>
         <source>Directory name</source>
-        <translation>Nazwa katalogu</translation>
+        <translation type="obsolete">Nazwa katalogu</translation>
     </message>
     <message>
         <source>mp3-tag Comment</source>
@@ -1778,6 +2059,10 @@ zostanie zmieniony na
         <source>Content</source>
         <translation>Zawartość</translation>
     </message>
+    <message>
+        <source>Media / Directory name</source>
+        <translation>Nośnik / Nazwa katalogu</translation>
+    </message>
 </context>
 <context>
     <name>helpDialog</name>
@@ -1923,6 +2208,91 @@ E-Mail: hyperr@freemail.hu
         <source>Importing csv...</source>
         <translation type="obsolete">Importuje csv...</translation>
     </message>
+    <message>
+        <source>Import was successful.</source>
+        <translation type="obsolete">Importowanie się powiodło.</translation>
+    </message>
+    <message>
+        <source>1 media</source>
+        <translation type="obsolete">1 nośnik</translation>
+    </message>
+    <message>
+        <source>media</source>
+        <translation type="obsolete">nośnik</translation>
+    </message>
+    <message>
+        <source>1 directory:,
+</source>
+        <translation type="obsolete">1 katalog:,
+</translation>
+    </message>
+    <message>
+        <source>directories</source>
+        <translation type="obsolete">katalogi</translation>
+    </message>
+    <message>
+        <source>1 File</source>
+        <translation type="obsolete">1 Plik</translation>
+    </message>
+    <message>
+        <source>files</source>
+        <translation type="obsolete">pliki</translation>
+    </message>
+    <message>
+        <source>are imported.</source>
+        <translation type="obsolete">zostało zimportowanych.</translation>
+    </message>
+    <message>
+        <source>Import successful</source>
+        <translation type="obsolete">Import sie powiódł</translation>
+    </message>
+    <message>
+        <source>file read error</source>
+        <translation type="obsolete">Błąd odczytu plik</translation>
+    </message>
+    <message>
+        <source>Fatal error</source>
+        <translation type="obsolete">Błąd krytyczny</translation>
+    </message>
+    <message>
+        <source>Fatal error occured.</source>
+        <translation type="obsolete">Nastąpił błąd krytyczny.</translation>
+    </message>
+    <message>
+        <source>file open error</source>
+        <translation type="obsolete">Błąd otwierania pliku</translation>
+    </message>
+    <message>
+        <source>importuser</source>
+        <translation type="obsolete">importuser</translation>
+    </message>
+    <message>
+        <source>Could not read the file</source>
+        <translation type="obsolete">Nie moge odczytać pliku</translation>
+    </message>
+    <message>
+        <source>Could not open the file</source>
+        <translation type="obsolete">Nie moge otworzyć pliku</translation>
+    </message>
+    <message>
+        <source>Could not read file</source>
+        <translation type="obsolete">Nie można odczytać pliku</translation>
+    </message>
+    <message>
+        <source>Could not open file</source>
+        <translation type="obsolete">Nie można otworzyć pliku</translation>
+    </message>
+    <message>
+        <source>Importing CSV...</source>
+        <translation type="obsolete">Importuje CSV...</translation>
+    </message>
+</context>
+<context>
+    <name>importGtktalogCsv</name>
+    <message>
+        <source>Importing CSV...</source>
+        <translation>Importuje CSV...</translation>
+    </message>
     <message>
         <source>Import was successful.</source>
         <translation>Importowanie się powiodło.</translation>
@@ -1933,7 +2303,7 @@ E-Mail: hyperr@freemail.hu
     </message>
     <message>
         <source>media</source>
-        <translation>nośnik</translation>
+        <translation>nośników</translation>
     </message>
     <message>
         <source>1 directory:,
@@ -1959,12 +2329,16 @@ E-Mail: hyperr@freemail.hu
     </message>
     <message>
         <source>Import successful</source>
-        <translation>Import sie powiódł</translation>
+        <translation>Importowanie sie powiódło</translation>
     </message>
     <message>
         <source>file read error</source>
         <translation>Błąd odczytu plik</translation>
     </message>
+    <message>
+        <source>Could not read file</source>
+        <translation>Nie można odczytać pliku</translation>
+    </message>
     <message>
         <source>Fatal error</source>
         <translation>Błąd krytyczny</translation>
@@ -1977,33 +2351,17 @@ E-Mail: hyperr@freemail.hu
         <source>file open error</source>
         <translation>Błąd otwierania pliku</translation>
     </message>
-    <message>
-        <source>importuser</source>
-        <translation>importuser</translation>
-    </message>
-    <message>
-        <source>Could not read the file</source>
-        <translation type="obsolete">Nie moge odczytać pliku</translation>
-    </message>
-    <message>
-        <source>Could not open the file</source>
-        <translation type="obsolete">Nie moge otworzyć pliku</translation>
-    </message>
-    <message>
-        <source>Could not read file</source>
-        <translation>Nie można odczytać pliku</translation>
-    </message>
     <message>
         <source>Could not open file</source>
         <translation>Nie można otworzyć pliku</translation>
     </message>
     <message>
-        <source>Importing CSV...</source>
-        <translation>Importuje CSV...</translation>
+        <source>importuser</source>
+        <translation>importuser</translation>
     </message>
 </context>
 <context>
-    <name>importXml</name>
+    <name>importGtktalogXml</name>
     <message>
         <source>Importing XML...</source>
         <translation>Importuje XML...</translation>
@@ -2018,7 +2376,7 @@ E-Mail: hyperr@freemail.hu
     </message>
     <message>
         <source>media</source>
-        <translation>nośniki</translation>
+        <translation>nośników</translation>
     </message>
     <message>
         <source>1 directory:,
@@ -2028,7 +2386,64 @@ E-Mail: hyperr@freemail.hu
     </message>
     <message>
         <source>directories</source>
-        <translation>katalogi</translation>
+        <translation>katalogów</translation>
+    </message>
+    <message>
+        <source>1 File</source>
+        <translation>1 Plik</translation>
+    </message>
+    <message>
+        <source>files</source>
+        <translation>plików</translation>
+    </message>
+    <message>
+        <source>are imported.</source>
+        <translation>zostało zimportowanych.</translation>
+    </message>
+    <message>
+        <source>Import successful</source>
+        <translation>Importowanie sie powiódło</translation>
+    </message>
+    <message>
+        <source>parse error</source>
+        <translation>błąd parsowania</translation>
+    </message>
+    <message>
+        <source>error during parsing</source>
+        <translation>błąd podczas parsowania</translation>
+    </message>
+    <message>
+        <source>importuser</source>
+        <translation>importuser</translation>
+    </message>
+</context>
+<context>
+    <name>importWhereIsItXml</name>
+    <message>
+        <source>Importing XML...</source>
+        <translation>Importuje XML...</translation>
+    </message>
+    <message>
+        <source>Importing XML from WhereIsIt was successful.</source>
+        <translation>Import XML&apos;a z WhereIsIt&apos;a powódł się.</translation>
+    </message>
+    <message>
+        <source>1 media</source>
+        <translation>1 nośnik</translation>
+    </message>
+    <message>
+        <source>media</source>
+        <translation>nośników</translation>
+    </message>
+    <message>
+        <source>1 directory:,
+</source>
+        <translation>1 katalog:,
+</translation>
+    </message>
+    <message>
+        <source>directories</source>
+        <translation>katalogów</translation>
     </message>
     <message>
         <source>1 File</source>
@@ -2054,9 +2469,62 @@ E-Mail: hyperr@freemail.hu
         <source>error during parsing</source>
         <translation>błąd podczas parsowania</translation>
     </message>
+</context>
+<context>
+    <name>importXml</name>
+    <message>
+        <source>Importing XML...</source>
+        <translation type="obsolete">Importuje XML...</translation>
+    </message>
+    <message>
+        <source>XML import was successful.</source>
+        <translation type="obsolete">Import XML zakończony sukcesem.</translation>
+    </message>
+    <message>
+        <source>1 media</source>
+        <translation type="obsolete">1 nośnik</translation>
+    </message>
+    <message>
+        <source>media</source>
+        <translation type="obsolete">nośniki</translation>
+    </message>
+    <message>
+        <source>1 directory:,
+</source>
+        <translation type="obsolete">1 katalog:,
+</translation>
+    </message>
+    <message>
+        <source>directories</source>
+        <translation type="obsolete">katalogi</translation>
+    </message>
+    <message>
+        <source>1 File</source>
+        <translation type="obsolete">1 Plik</translation>
+    </message>
+    <message>
+        <source>files</source>
+        <translation type="obsolete">plików</translation>
+    </message>
+    <message>
+        <source>are imported.</source>
+        <translation type="obsolete">zostało zimportowanych.</translation>
+    </message>
+    <message>
+        <source>Import successful</source>
+        <translation type="obsolete">Import sie powiódł</translation>
+    </message>
+    <message>
+        <source>parse error</source>
+        <translation type="obsolete">błąd parsowania</translation>
+    </message>
+    <message>
+        <source>error during parsing</source>
+        <translation type="obsolete">błąd podczas parsowania</translation>
+    </message>
     <message>
         <source>importuser</source>
-        <translation>importuser</translation>
+        <translation type="obsolete">importuser</translation>
     </message>
 </context>
 <context>
@@ -2093,6 +2561,10 @@ E-Mail: hyperr@freemail.hu
         <source>Cancel</source>
         <translation>Anuluj</translation>
     </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source> </source>
         <translation type="unfinished"></translation>
@@ -2132,6 +2604,10 @@ E-Mail: hyperr@freemail.hu
         <source>The new (media) name must be unique!</source>
         <translation>Nowa nazwa (nośnika) musi być unikatowa!</translation>
     </message>
+    <message>
+        <source>The new media name can&apos;t starts with &quot;@&quot; !</source>
+        <translation>Nowa nazwa nośnika nie może zaczynać się od znaku &quot;@&quot;!</translation>
+    </message>
 </context>
 <context>
     <name>renumberdialog</name>
@@ -2165,12 +2641,16 @@ E-Mail: hyperr@freemail.hu
     </message>
     <message>
         <source>I Cannot understand the text as number!</source>
-        <translation>Nie rozpoznaje w tym liczby!</translation>
+        <translation type="obsolete">Nie rozpoznaje w tym liczby!</translation>
     </message>
     <message>
         <source>The new media-number must be unique!</source>
         <translation>Nowy numer nośnika musi być unikatowa!</translation>
     </message>
+    <message>
+        <source>Please enter number value!</source>
+        <translation>Prosze wprowadzic wartość liczbową!</translation>
+    </message>
 </context>
 <context>
     <name>seekEngine</name>
@@ -2198,5 +2678,9 @@ E-Mail: hyperr@freemail.hu
         <source>error</source>
         <translation>błąd</translation>
     </message>
+    <message>
+        <source>media</source>
+        <translation>Nośnik</translation>
+    </message>
 </context>
 </TS>
