@@ -25,7 +25,7 @@
  *
  *Copyright Piotr "|TEcHNO|" Lewandowski, 2004
  */
-#include <iostream.h>
+//#include <iostream> for debug only
 #include <stdio.h>
 #include <malloc.h>
 #include <qstring.h>
@@ -253,7 +253,13 @@ struct INFOLIST{
 
 unsigned int allcCount=0;/*temportarily used for additional data stored after waveH*/
 
+#include <iostream>
+
 QString parseAviHeader(FILE* file){
+	long filelength=0;
+	
+	fseek(file, 0L, SEEK_END);
+	filelength=ftell(file);
 	rewind(file); /*fseek(stream, 0L, SEEK_SET);*/
 	QString ReturnData="";
 	/*
@@ -261,6 +267,9 @@ QString parseAviHeader(FILE* file){
 	 *Since these are structs, we can point at the beginning and 
 	 *overflow to other memebers.
 	 */
+        if(filelength-ftell(file) < (long)sizeof(unsigned long int) * (3+3+16+3+16+3))
+	      return QObject::tr("Not a RIFF/AVI file OR header broken!");
+	      
 	fread((void*)&topHeader.header,sizeof(unsigned long int),3,file);
 	if(topHeader.header.hex!=RIFF&&topHeader.fType.hex!=_AVI){
 		#ifdef DoAviDebug
@@ -343,15 +352,21 @@ QString parseAviHeader(FILE* file){
 		return ReturnData;
 		}
 	fseek(file,12,SEEK_CUR);
+        if(filelength-ftell(file) < (long)sizeof(unsigned long int) * 1)
+	      return QObject::tr("Not a RIFF/AVI file OR header broken!");
 	fread((void*)&strfFourCC.hex,sizeof(unsigned long int),1,file);
 	fseek(file,strf.fSize-20,SEEK_CUR);
 	fread((void*)&junk.header.hex,sizeof(unsigned long int),3,file);
+
 	if(junk.header.hex!=JUNK){
 		fseek(file,-12,SEEK_CUR);
 		}
 	else{
 		fseek(file, junk.fSize-4, SEEK_CUR);
 		};
+
+        if(filelength-ftell(file) < (long)sizeof(unsigned long int) * 21)
+	      return QObject::tr("Not a RIFF/AVI file OR header broken!");
 	fread((void*)&list1.header.hex,sizeof(unsigned long int),3,file);
 	fread((void*)&streamH2.fcc.hex,sizeof(unsigned long int),16,file);
 	fread((void*)&strf2.header.hex,sizeof(unsigned long int),3,file);
@@ -378,11 +393,18 @@ QString parseAviHeader(FILE* file){
 		return ReturnData;
 		};
 	fseek(file,-4,SEEK_CUR);
+        if(filelength-ftell(file) < (long)sizeof(short int) * 9)
+	      return QObject::tr("Not a RIFF/AVI file OR header broken!");
 	fread((void*)&waveH.wFormatTag.hex,sizeof(short int),9,file);
 	if(waveH.cbSize>0){
 		allcCount=(waveH.cbSize/4)+(waveH.cbSize%4>0?1:0);
 		int i=0;
+		
+		if(filelength-ftell(file) < (long)(allcCount *sizeof(long int)))
+	    	    return QObject::tr("Not a RIFF/AVI file OR header broken!");
 		while(i<(int)allcCount){
+		        if(i>=10) break; //have to end the loop becuse we alloc the "allc" only 10 element 
+			                 //(caused seg. fault. with some .avi)
 			fread((void*)&allc[i].hex,sizeof(long int),1,file);
 			i++;
 			};
@@ -415,6 +437,9 @@ QString parseAviHeader(FILE* file){
 			};
 		};
 	fseek(file,-4,SEEK_CUR);
+	
+        if(filelength-ftell(file) < 4*3)
+	      return QObject::tr("Not a RIFF/AVI file OR header broken!");
 	fread((void*)&listI.header.hex,4,3,file);
 	/*
 	 *We skip ODML data for now
@@ -423,7 +448,7 @@ QString parseAviHeader(FILE* file){
 		listDW.hex=0x00000000; /*clear data*/
 		while(listDW.hex!=LIST){
 			fread((void*)&listDW.txt[0],sizeof(char),1,file);
-			if((int)listDW.txt[0]==EOF)  return ReturnData;
+			if((int)listDW.txt[0]==EOF)  return ReturnData;      
 			if((int)listDW.txt[0]==0x4c)fread((void*)&listDW.txt[1],sizeof(char),1,file);
 			if((int)listDW.txt[1]==0x49){
 				fread((void*)&listDW.txt[2],sizeof(char),1,file);
@@ -437,6 +462,8 @@ QString parseAviHeader(FILE* file){
 	/*
 	 *now we are somewhere around LIST/INFO
 	 */
+        if(filelength-ftell(file) < 4 * 3)
+	      return QString("Broken header");
 	fread((void*)&listI2.header.hex,4,3,file);
 	if(listI2.fType.hex==INFO){
 		while(infoH.header.hex!=JUNK&&infoH.header.hex!=LIST){
